# django-calaccess-campaign-browser

A Django app to refine, review and investigate campaign finance data drawn from the California Secretary of State’s CAL-ACCESS database

[![Build Status](https://travis-ci.org/california-civic-data-coalition/django-calaccess-campaign-browser.png?branch=master)](https://travis-ci.org/california-civic-data-coalition/django-calaccess-campaign-browser)
[![PyPI version](https://badge.fury.io/py/django-calaccess-campaign-browser.png)](http://badge.fury.io/py/django-calaccess-campaign-browser)
[![Coverage Status](https://coveralls.io/repos/california-civic-data-coalition/django-calaccess-campaign-browser/badge.png?branch=master)](https://coveralls.io/r/california-civic-data-coalition/django-calaccess-campaign-browser?branch=master)

* Documentation: [django-calaccess-campaign-browser.rtfd.org](http://django-calaccess-campaign-browser.rtfd.org)
* Issues: [https://github.com/california-civic-data-coalition/django-calaccess-campaign-browser/issues](https://github.com/california-civic-data-coalition/django-calaccess-campaign-browser/issues)
* Packaging: [https://pypi.python.org/pypi/django-calaccess-campaign-browser](https://pypi.python.org/pypi/django-calaccess-campaign-browser)
* Testing: [https://travis-ci.org/california-civic-data-coalition/django-calaccess-campaign-browser](https://travis-ci.org/california-civic-data-coalition/django-calaccess-campaign-browser)
* Coverage: [https://coveralls.io/r/california-civic-data-coalition/django-calaccess-campaign-browser](https://coveralls.io/r/california-civic-data-coalition/django-calaccess-campaign-browser)
